@@ -5,10 +5,15 @@ from fabric.api import *
 from fabric.utils import _AttributeDict
 
 
-ez_env=_AttributeDict({
+ez_env = _AttributeDict({
     'group': None,
 })
 
+ez_cloud = _AttributeDict({
+    'qingcloud': None,
+})
+
+
 def _pssh(file):
     """
     Parse pssh-like file
@@ -16,11 +21,11 @@ def _pssh(file):
     """
     file = os.path.realpath(os.path.expanduser(file))
 
-    with open(file,'r') as fp:
+    with open(file, 'r') as fp:
         buffer = fp.read()
 
-    host_list=buffer.strip("\n").split("\n")
-    machines=[]
+    host_list = buffer.strip("\n").split("\n")
+    machines = []
     for addr in host_list[:]:
         addr.strip()
         if addr.find('#') == -1:
@@ -29,17 +34,16 @@ def _pssh(file):
     return machines
 
 
-
 def _bind_pssh(file):
     """
     Bind env from pssh-like file
     :param file:
     """
-    env.hosts=_pssh(file)
+    env.hosts = _pssh(file)
     env.use_ssh_config = True
 
 
-def bind_hosts(curr,routes):
+def bind_hosts(curr, routes):
     """
     bind hosts from file
     :param curr:
@@ -49,7 +53,7 @@ def bind_hosts(curr,routes):
 
     ez_env.group = curr
 
-    for k,v in routes.items():
+    for k, v in routes.items():
         if k == curr:
             _bind_pssh(v)
             break
@@ -59,3 +63,15 @@ def bind_hosts(curr,routes):
 
 
 
+def bind_cloud(qingcloud=None,**kwargs):
+
+    if qingcloud:
+        ez_cloud.qingcloud = qingcloud
+
+
+    pass
+
+
+
+
+
