@@ -80,7 +80,6 @@ def server_redis(card=None, size=None, newer='remi'):
     run('chown redis.redis /storage/redis')
     run('chkconfig --level 35 redis on')
 
-
     if card:
         ip = cmd_ip(card)
     else:
@@ -170,9 +169,13 @@ def server_gitolite(pubkey=None):
     pass
 
 
-def server_supervisor(user='webuser', tmp='/tmp', log_dir='/logs/supervisor', log_level='info'):
+def server_supervisor(user=None, variable=None, pip_path=None, log_dir='/logs/supervisor', log_level='info'):
     """
     Install supervisor
+    Default depends pypy
+    Focus on tornado
+
+    *note* current, don't use root account
     """
 
     # yum supervisor id tooooooooooooooooo old
@@ -192,13 +195,28 @@ def server_supervisor(user='webuser', tmp='/tmp', log_dir='/logs/supervisor', lo
 
     # run('chkconfig --level 35 supervisord on')
 
+    # default is python_root
+
+
+
+    io_slowlog('supervisor')
+
+    pip('supervisor', pip_path=pip_path)
+    # pip('supervisor-logging', pip_path=pip_path)
+
+    if not pip_path:
+        python_root = '/usr/local/pypy/bin'
+
+    run('ln -snf {}/supervisord /usr/local/bin/supervisord'.format(python_root))
+    run('ln -snf {}/supervisorctl /usr/local/bin/supervisorctl'.format(python_root))
+
+    # with settings(warn_only=True):
+    # if run('cat /etc/rc.local | grep "/usr/local/bin/supervisord"').failed:
+    #         run('echo "/usr/local/bin/supervisord -c  /etc/supervisord.conf " >> /etc/rc.local')
 
     with settings(warn_only=True):
-        if run('cat /etc/rc.local | grep "/usr/local/bin/supervisord"').failed:
-            run('echo "/usr/local/bin/supervisord -c  /etc/supervisord.conf " >> /etc/rc.local')
-
-    with settings(warn_only=True):
-        run('test -d /etc/supervisor.d || mkdir /etc/supervisor.d')
+        run('mkdir /etc/supervisor.d')
+        pass
 
     try:
         template = pkg_resources.resource_string('fabez', 'tpl/supervisord.conf')
@@ -206,12 +224,20 @@ def server_supervisor(user='webuser', tmp='/tmp', log_dir='/logs/supervisor', lo
         template = open(os.path.join(os.path.dirname(__file__), 'tpl', 'supervisord.conf')).read()
         pass
 
-    buf = template.replace('{$username}', user) \
-        .replace('{$tmp}', tmp) \
-        .replace('{$logs}', log_dir) \
+    buf = template.replace('{$logs}', log_dir) \
         .replace('{$log_level}', log_level)
 
 
+    replace_variable = 'environment='
+
+    if variable:
+        replace_variable = '{},'.format(variable)
+
+    replace_variable += 'PYTHONUNBUFFERED="x"'
+
+    buf = buf.replace('{$variable}', replace_variable)
+
+
     # only support python2.x
     with tempfile.NamedTemporaryFile('w', delete=False) as fh:
         print>> fh, buf
@@ -219,6 +245,25 @@ def server_supervisor(user='webuser', tmp='/tmp', log_dir='/logs/supervisor', lo
     put(fh.name, '/etc/supervisord.conf')
     os.remove(fh.name)
 
+    try:
+        template = pkg_resources.resource_string('fabez', 'tpl/supervisord.start')
+    except:
+        template = open(os.path.join(os.path.dirname(__file__), 'tpl', 'supervisord.start')).read()
+        pass
+
+    buf = template
+
+    # only support python2.x
+    with tempfile.NamedTemporaryFile('w', delete=False) as fh:
+        print>> fh, buf
+
+    put(fh.name, '/etc/init.d/supervisord')
+    run('chmod +x /etc/init.d/supervisord')
+
+    os.remove(fh.name)
+
+    run('chkconfig --level 35 supervisord on')
+
     pass
 
 
@@ -659,7 +704,7 @@ def server_statsdsuite(user='webuser', monit=None):
 # # yum remove sendmail
 #
 #
-#     pass
+# pass
 
 
 def server_smtp(host, domain, networks):
@@ -703,16 +748,35 @@ def restart_web(config=None):
     run('service tengine restart')
 
 
-def reboot_monit(name, config=None):
+def restart_monit(config=None):
+
     if config:
         config_monit(config)
         run('service monit restart')
 
-    run('monit restart {}'.format(name))
+    pass
+
+
+def reboot_monit(name=None, config=None):
+    if config:
+        config_monit(config)
+        run('service monit restart')
+
+    if name:
+        run('monit restart {}'.format(name))
     # run('service monit restart')
 
 
 
+def reboot_supervisor(name=None, config=None):
+    if config:
+        config_supervisor(config)
+        run('service supervisord restart')
+
+    if name:
+        run('supervisorctl restart {}'.format(name))
+
+
 
 
 
